<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>AsciiFile</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="37"/>
        <location filename="../asciifile/asciifile.cpp" line="43"/>
        <source>Read ascii points</source>
        <translation>Точки в формате ASCII</translation>
    </message>
</context>
<context>
    <name>ImportShp</name>
    <message>
        <source>shape file</source>
        <translation type="obsolete">Shape-файл</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="40"/>
        <source>Import ESRI Shapefile</source>
        <translation>Импорт ESRI Shape-файла</translation>
    </message>
</context>
<context>
    <name>LC_Align</name>
    <message>
        <location filename="../align/align.cpp" line="20"/>
        <location filename="../align/align.cpp" line="27"/>
        <source>Align</source>
        <translation>Выровнять</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="40"/>
        <source>first base point:</source>
        <translation>Первая базовая точка:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="42"/>
        <source>first target point:</source>
        <translation>Первая целевая точка:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="44"/>
        <source>second base point:</source>
        <translation>Вторая базовая точка:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="46"/>
        <source>second target point:</source>
        <translation>Вторая целевая точка:</translation>
    </message>
</context>
<context>
    <name>LC_List</name>
    <message>
        <location filename="../list/list.cpp" line="23"/>
        <location filename="../list/list.cpp" line="30"/>
        <source>List entities</source>
        <translation>Перечень элементов</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="46"/>
        <source>n</source>
        <translation>№</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="60"/>
        <source>Empty Entity</source>
        <translation>Пусто</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="67"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="67"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="73"/>
        <source>Layer</source>
        <translation>Слой</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="75"/>
        <source>Color</source>
        <translation>Цвет</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="76"/>
        <source>Line type</source>
        <translation>Тип линии</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="77"/>
        <source>Line thickness</source>
        <translation>Толщина линии</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="78"/>
        <source>ID</source>
        <translation>Идентификатор</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="84"/>
        <source>POINT</source>
        <translation>ТОЧКА</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="85"/>
        <location filename="../list/list.cpp" line="195"/>
        <source>in point</source>
        <translation>в точке</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="90"/>
        <source>LINE</source>
        <translation>ЛИНИЯ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="95"/>
        <source>from point</source>
        <translation>от точки</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="98"/>
        <source>to point</source>
        <translation>до точки</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="103"/>
        <location filename="../list/list.cpp" line="127"/>
        <source>length</source>
        <translation>длина</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="108"/>
        <source>Angle in XY plane</source>
        <translation>угол в плоскости XY</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="109"/>
        <source>Inc.</source>
        <translation>ув.</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="114"/>
        <source>ARC</source>
        <translation>ДУГА</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="115"/>
        <location filename="../list/list.cpp" line="131"/>
        <location filename="../list/list.cpp" line="141"/>
        <source>center point</source>
        <translation>центральная точка</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="121"/>
        <location filename="../list/list.cpp" line="135"/>
        <location filename="../list/list.cpp" line="199"/>
        <source>radius</source>
        <translation>радиус</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="122"/>
        <source>initial angle</source>
        <translation>начальный угол</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="123"/>
        <source>final angle</source>
        <translation>конечный угол</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="130"/>
        <source>CIRCLE</source>
        <translation>ОКРУЖНОСТЬ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="136"/>
        <source>circumference</source>
        <translation>периметр</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="137"/>
        <source>area</source>
        <translation>площадь</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="140"/>
        <source>ELLIPSE</source>
        <translation>ЭЛЛИПС</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="144"/>
        <source>major axis</source>
        <translation>главные оси</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="162"/>
        <source>CONSTRUCTIONLINE</source>
        <translation>ЛИНИЯПОСТРОЕНИЯ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="165"/>
        <source>OVERLAYBOX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="168"/>
        <source>SOLID</source>
        <translation>СПЛОШНОЙ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="172"/>
        <source>MTEXT</source>
        <translation>МНОГОСТРОЧНЫЙ ТЕКСТ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="175"/>
        <source>TEXT</source>
        <translation>ТЕКСТ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="178"/>
        <source>INSERT</source>
        <translation>ВСТАВКА</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="181"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="182"/>
        <source>Insertion point</source>
        <translation>Точка вставки</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="187"/>
        <source>POLYLINE</source>
        <translation>ЛОМАНАЯ ЛИНИЯ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="188"/>
        <source>Closed</source>
        <translation>Замкнута</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="189"/>
        <source>No</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="189"/>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="190"/>
        <source>Vertices</source>
        <translation>Вершины</translation>
    </message>
    <message>
        <source>curvature</source>
        <translation type="obsolete">кривизна</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="204"/>
        <source>IMAGE</source>
        <translation>ИЗОБРАЖЕНИЕ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="207"/>
        <source>SPLINE</source>
        <translation>СПЛАЙН</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="210"/>
        <source>SPLINEPOINTS</source>
        <translation>ТОЧКИСПЛАЙНА</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="213"/>
        <source>HATCH</source>
        <translation>ШТРИХОВКА</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="216"/>
        <source>DIMLEADER</source>
        <translation>РАЗМЕР-ВЫНОСКА</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="219"/>
        <source>DIMALIGNED</source>
        <translation>РАЗМЕР ВЫРАВНЕННЫЙ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="222"/>
        <source>DIMLINEAR</source>
        <translation>РАЗМЕР ЛИНЕЙНЫЙ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="225"/>
        <source>DIMRADIAL</source>
        <translation>РАЗМЕР РАДИАЛЬНЫЙ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="228"/>
        <source>DIMDIAMETRIC</source>
        <translation>РАЗМЕР ДИАМЕТРАЛЬНЫЙ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="231"/>
        <source>DIMANGULAR</source>
        <translation>РАЗМЕР УГЛОВОЙ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="234"/>
        <source>UNKNOWN</source>
        <translation>НЕИЗВЕСТНО</translation>
    </message>
</context>
<context>
    <name>LC_SameProp</name>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="21"/>
        <location filename="../sameprop/sameprop.cpp" line="28"/>
        <source>Same properties</source>
        <translation>Одинаковые свойства</translation>
    </message>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="41"/>
        <source>select original entity:</source>
        <translation>Выберите исходный объект</translation>
    </message>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="43"/>
        <source>select entities to change</source>
        <translation>Выберите объекты для изменения</translation>
    </message>
</context>
<context>
    <name>LC_Sample</name>
    <message>
        <location filename="../sample/sample.cpp" line="26"/>
        <location filename="../sample/sample.cpp" line="33"/>
        <source>Sample plugin</source>
        <translation>Пример дополнения</translation>
    </message>
</context>
<context>
    <name>PicFile</name>
    <message>
        <location filename="../picfile/picfile.cpp" line="38"/>
        <source>Read PIC file</source>
        <translation>PIC-файл</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="44"/>
        <source>import PIC file</source>
        <translation>Импорт PIC-файла</translation>
    </message>
</context>
<context>
    <name>dibPunto</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="235"/>
        <source>Read ascii points</source>
        <translation>Точки в формате ASCII</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="241"/>
        <source>File...</source>
        <translation>Файл...</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="248"/>
        <source>Format:</source>
        <translation>Формат:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>Space Separator</source>
        <translation>Разделение пробелами</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>Tab Separator</source>
        <translation>Разделение табуляцией</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>Comma Separator</source>
        <translation>Разделение запятой</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>Space in Columns</source>
        <translation>Пробелы в столбцах</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>*.odb for Psion 2</source>
        <translation>*.odb для Psion 2</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="252"/>
        <source>Connect points</source>
        <translation>Соединить точки</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="260"/>
        <source>2D Point</source>
        <translation>2D точка</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="260"/>
        <source>Draw 2D Point</source>
        <translation>Построить 2D точку</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="261"/>
        <source>3D Point</source>
        <translation>3D точка</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="261"/>
        <source>Draw 3D Point</source>
        <translation>Построить 3D точку</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="262"/>
        <source>Point Number</source>
        <translation>Номер точки</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="262"/>
        <source>Draw point number</source>
        <translation>Нумеровать точки</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="263"/>
        <source>Point Elevation</source>
        <translation>Отметка высоты</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="263"/>
        <source>Draw point elevation</source>
        <translation>Надписать высоту точки</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="264"/>
        <source>Point Code</source>
        <translation>Код точки</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="264"/>
        <source>Draw point code</source>
        <translation>Надписать код точки</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="278"/>
        <source>Accept</source>
        <translation>Применить</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="283"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="313"/>
        <source>Select file</source>
        <translation>Выберите файл</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="320"/>
        <source>Point 2D layer is empty</source>
        <translation>Слой для 2D точек пуст</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="323"/>
        <source>Point 3D layer is empty</source>
        <translation>Слой для 3D точек пуст</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="326"/>
        <source>Point elevation layer is empty</source>
        <translation>Не указан слой для высоты точки</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="327"/>
        <source>Point elevation height is empty</source>
        <translation>Не указана высота шрифта высоты точки</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="328"/>
        <source>Point elevation separation is empty</source>
        <translation>Не указано разделение высоты точки</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="331"/>
        <source>Point number layer is empty</source>
        <translation>Не указан слой нумерации точки</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="332"/>
        <source>Point number height is empty</source>
        <translation>Не указана высота шрифта нумерации точки</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="333"/>
        <source>Point number separation is empty</source>
        <translation>Не указано разделение нумерации точки</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="336"/>
        <source>Point code layer is empty</source>
        <translation>Не указан слой кода точки</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="337"/>
        <source>Point code height is empty</source>
        <translation>Не указана высота шрифта кода точки</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="338"/>
        <source>Point code separation is empty</source>
        <translation>Не указано разделение кода точки</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="366"/>
        <source>The file %1 not exist</source>
        <translation>Не существует файл %1</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="371"/>
        <source>Can&apos;t open the file %1</source>
        <translation>Невозможно открыть файл %1</translation>
    </message>
</context>
<context>
    <name>dibSHP</name>
    <message>
        <location filename="../importshp/importshp.cpp" line="59"/>
        <source>File...</source>
        <translation>Файл...</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="67"/>
        <source>File type:</source>
        <translation>Тип файла:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="75"/>
        <source>Layer</source>
        <translation>Слой</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="56"/>
        <source>Import ESRI Shapefile</source>
        <translation>Импорт ESRI Shape-файла</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="68"/>
        <location filename="../importshp/importshp.cpp" line="266"/>
        <source>Unknown</source>
        <translation>Неизвестно</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="76"/>
        <location filename="../importshp/importshp.cpp" line="89"/>
        <location filename="../importshp/importshp.cpp" line="102"/>
        <location filename="../importshp/importshp.cpp" line="115"/>
        <source>Current</source>
        <translation>Текущий</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="77"/>
        <location filename="../importshp/importshp.cpp" line="90"/>
        <location filename="../importshp/importshp.cpp" line="103"/>
        <location filename="../importshp/importshp.cpp" line="116"/>
        <source>From data:</source>
        <translation>Из данных:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="88"/>
        <source>Color</source>
        <translation>Цвет</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="101"/>
        <source>Line type</source>
        <translation>Тип линии</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="114"/>
        <source>Width</source>
        <translation>Ширина</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="127"/>
        <location filename="../importshp/importshp.cpp" line="213"/>
        <source>Point</source>
        <translation>Точка</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="128"/>
        <source>as Point</source>
        <translation>Как точка</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="129"/>
        <source>as Label:</source>
        <translation>Как метка:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="141"/>
        <source>Accept</source>
        <translation>Принять</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="142"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="167"/>
        <source>Select file</source>
        <translation>Выберите файл</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="217"/>
        <source>Point+Measure</source>
        <translation>Точка+измерение</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="221"/>
        <source>3D Point</source>
        <translation>3D точка</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="225"/>
        <source>Multi Point</source>
        <translation>Мультиточка</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="229"/>
        <source>Multi Point+Measure</source>
        <translation>Мультиточка+измерение</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="233"/>
        <source>3D Multi Point</source>
        <translation>3D мультиточка</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="237"/>
        <source>Arc</source>
        <translation>Дуга</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="241"/>
        <source>Arc+Measure</source>
        <translation>Дуга+измерение</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="245"/>
        <source>3D Arc</source>
        <translation>3D дуга</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="249"/>
        <source>Polygon</source>
        <translation>Многоугольник</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="253"/>
        <source>Polygon+Measure</source>
        <translation>Многоугольник+измерение</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="257"/>
        <source>3D Polygon</source>
        <translation>3D многоугольник</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="261"/>
        <source>Multipatch</source>
        <translation>Мультивключение</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="281"/>
        <source>The file %1 not have extension .shp</source>
        <translation>У файла %1 расширение не .shp</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="286"/>
        <source>The file %1 not exist</source>
        <translation>Не существует файла %1</translation>
    </message>
</context>
<context>
    <name>lc_Listdlg</name>
    <message>
        <location filename="../list/list.cpp" line="251"/>
        <source>List entities</source>
        <translation>Перечень элементов</translation>
    </message>
</context>
<context>
    <name>lc_Sampledlg</name>
    <message>
        <location filename="../sample/sample.cpp" line="54"/>
        <source>Draw line</source>
        <translation>Начертить линию</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="60"/>
        <source>Start X:</source>
        <translation>Начало X:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="66"/>
        <source>Start Y:</source>
        <translation>Начало Y:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="72"/>
        <source>End X:</source>
        <translation>Конец X:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="78"/>
        <source>End Y:</source>
        <translation>Конец Y:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="86"/>
        <source>Accept</source>
        <translation>Принять</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="91"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="107"/>
        <source>Start X is empty</source>
        <translation>Пустая начальная X-координата</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="108"/>
        <source>Start Y is empty</source>
        <translation>Пустая начальная Y-координата</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="109"/>
        <source>End X is empty</source>
        <translation>Пустая конечная X-координата</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="110"/>
        <source>End Y is empty</source>
        <translation>Пустая конечная Y-координата</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="132"/>
        <source>Sample plugin</source>
        <translation>Пример дополнения</translation>
    </message>
</context>
<context>
    <name>picPunto</name>
    <message>
        <location filename="../picfile/picfile.cpp" line="67"/>
        <source>File...</source>
        <translation>Файл...</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="77"/>
        <source>Scale:</source>
        <translation>Масштаб:</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="81"/>
        <source>Accept</source>
        <translation>Применить</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="85"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="113"/>
        <source>Select file</source>
        <translation>Выберите файл</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="121"/>
        <source>Scale Factor is empty or invalid</source>
        <translation>Масштаб не указан или неверен</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="134"/>
        <source>The file %1 not exist</source>
        <translation>Файл %1 не существует</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="139"/>
        <source>Can&apos;t open the file %1</source>
        <translation>Невозможно открыть файл %1</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="146"/>
        <source>%1 objects imported</source>
        <translation>%1 объектов импортировано</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="168"/>
        <source>picPunto drawLine: first point is empty %1</source>
        <translation>picPunto drawLine: пустая первая точка %1</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="181"/>
        <source>picPunto drawLine: next point is empty %1</source>
        <translation>picPunto drawLine: пустая следующая точка %1</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="260"/>
        <location filename="../picfile/picfile.cpp" line="269"/>
        <source>format error in %1</source>
        <translation>ошибка формата в %1</translation>
    </message>
</context>
<context>
    <name>plot</name>
    <message>
        <location filename="../plotequation/plot.cpp" line="21"/>
        <location filename="../plotequation/plot.cpp" line="28"/>
        <source>Plot plugin</source>
        <translation>График (дополнение)</translation>
    </message>
    <message>
        <location filename="../plotequation/plot.cpp" line="28"/>
        <source>Draw</source>
        <translation>Построить</translation>
    </message>
</context>
<context>
    <name>plotDialog</name>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="15"/>
        <source>Plot equation</source>
        <translation>График выражения</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="18"/>
        <source>This plugin allows you to plot mathematical equations.
If you don&apos;t want to use the parametric form, just leave out &quot;Equation2&quot;.
You can use pi when you need the value of pi (i.e. (3*pi)).
Use t or x in your equation as a variable/parameter.
</source>
        <translation>Дополнение позволяет строить график математического выражения.
Если не требуется параметрическая форма, не используйте «Выражение 2».
Можно использовать pi, если требуется значение числа ¶, например (3*pi).
В выражениях используйте t или x как переменную или параметр.
</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="22"/>
        <source>Equation 1:</source>
        <translation>Выражение 1:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="23"/>
        <source>Equation 2:</source>
        <translation>Выражение 2:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="26"/>
        <source>start value:</source>
        <translation>Начальное значение:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="27"/>
        <source>end value:</source>
        <translation>Конечное значение:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="28"/>
        <source>step size:</source>
        <translation>Приращение:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="32"/>
        <source>Draw</source>
        <translation>Построить</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="33"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="59"/>
        <source>Line Segments</source>
        <comment>Plot Equation to generate RS_Line segments</comment>
        <translation>Линейные сегменты</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="60"/>
        <source>Polyline</source>
        <comment>Plot Equation to generate RS_Polyline</comment>
        <translation>Ломаная</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="61"/>
        <source>SplinePoints</source>
        <comment>Plot Equation to generate 2nd spline by LC_SplinePoints</comment>
        <translation>Точки сплайна</translation>
    </message>
</context>
<context>
    <name>pointBox</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="177"/>
        <source>Layer:</source>
        <translation>Слой:</translation>
    </message>
</context>
<context>
    <name>textBox</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="210"/>
        <source>Style:</source>
        <translation>Стиль:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="211"/>
        <source>Height:</source>
        <translation>Высота:</translation>
    </message>
    <message>
        <source>Heigth:</source>
        <translation type="obsolete">Высота:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="212"/>
        <source>Separation</source>
        <translation>Разделение:</translation>
    </message>
</context>
</TS>
